@@ -2,6 +2,8 @@ from zencad.scene import Scene
 from zenframe.configuration import Configuration
 
 NOSHOW = False
+DISPLAY = None
+ANIMATE_THREAD = None
 
 # UNBOUND_MODE = False  # Устанавливается из zencad.gui.display_unbounded
 # сигнализирует об активации подчинённого режима работы
@@ -32,41 +34,40 @@ def highlight(shp, color=(1, 0, 0, 0.5), deep=True, scene=None):
     return shp
 
 
-def hl(*args, **kwargs): return highlight(*args, **kwargs)
-
-
-ANIMATE_THREAD = None
+def hl(*args, **kwargs):
+    return highlight(*args, **kwargs)
 
 
 def widget_creator(communicator, scene, animate, preanimate, close_handle, animate_step=0.01):
     import zencad.animate
     import zenframe.finisher
 
+    global DISPLAY
     global ANIMATE_THREAD
     from zencad.gui.display import DisplayWidget
-    display = DisplayWidget(
+    DISPLAY = DisplayWidget(
         communicator=communicator)
-    display.attach_scene(scene)
+    DISPLAY.attach_scene(scene)
 
     # todo: почему не внутри?
-    communicator.bind_handler(display.external_communication_command)
+    communicator.bind_handler(DISPLAY.external_communication_command)
 
     if close_handle:
         zenframe.finisher.register_destructor(None, close_handle)
 
     if animate:
         animate_thread = zencad.animate.AnimateThread(
-            widget=display,
+            widget=DISPLAY,
             updater_function=animate,
             animate_step=animate_step)
 
         if preanimate:
-            preanimate(display, animate_thread)
+            preanimate(DISPLAY, animate_thread)
 
         animate_thread.start()
         ANIMATE_THREAD = animate_thread
 
-    return display
+    return DISPLAY
 
 
 def show(scene=None, animate=None, preanimate=None, close_handle=None, animate_step=0.01, display_only=False):
@@ -94,7 +95,7 @@ def show(scene=None, animate=None, preanimate=None, close_handle=None, animate_s
         # главной оболочки.
         import zencad.gui.display_only
         zencad.gui.display_only.init_display_only_mode()
-        zencad.gui.display_only.DISPLAY.attach_scene(scene)
+        DISPLAY.attach_scene(scene)
         zencad.gui.display_only.exec_display_only_mode()
 
     else:
